@@ -119,7 +119,7 @@ class LinuxDevice(object):
     '''
     A base class for common linux devices.
     '''
-    version = '0.49'
+    version = '1.0.3'
 
     LOG_EMERG = 0   # not used
     LOG_ALERT = 1   # not used
@@ -170,7 +170,9 @@ class LinuxDevice(object):
             u = urlparse.urlparse(server and server or self["url"])
             q = urlparse.parse_qs(u.query)
 
-            self["scheme"] = u.scheme
+            self["scheme"] = (u.scheme == "ssh") and\
+                    (u.scheme + " -o GSSAPIAuthentication=no") or\
+                    u.scheme
             self["username"] = u.username
             self["password"] = u.password
             self["hostname"] = u.hostname
@@ -498,8 +500,9 @@ class LinuxDevice(object):
         @ bg_color: The log background color of the text.
 
         '''
-        level = log_level and log_level or level
-        if level > self["log_level"] or (not kwargs.get("with_log", True)):
+        log_level = log_level and log_level or self["log_level"]
+        #print("level: %d, log_level: %d" %(level, log_level))
+        if level > log_level or (not kwargs.get("with_log", True)):
             return
 
         #print "aaa:%s, bbb" %(leading)
@@ -548,7 +551,7 @@ class LinuxDevice(object):
         for i in range(1, count + 1):
             progress = int(i * ratio)
             str = char * progress + ' ' * (total - progress)
-            sys.stdout.write('\r%s %s/%s[%s][%s%%]'%(description, i/10, timeout,
+            sys.stdout.write('\r%s %s/%s[%s][%d%%]'%(description, i/10, timeout,
                 str, i * 100 / count))
             sys.stdout.flush()
             time.sleep(0.1)
